#ifndef NT2_INCLUDE_FUNCTIONS_ROR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ROR_HPP_INCLUDED

#include <nt2/bitwise/include/functions/ror.hpp>

#endif
